ngSubmit property
An event fired with the user has triggered a form submission.
Implementation
@Output()
Stream<T> get ngSubmit => _ngSubmit.stream;
An event fired with the user has triggered a form submission.
@Output()
Stream<T> get ngSubmit => _ngSubmit.stream;