onDisabledChanged abstract method
This function is called when the control status changes to or from "DISABLED".
Depending on the value, it will enable or disable the appropriate DOM element.
Implementation
void onDisabledChanged(bool isDisabled);
This function is called when the control status changes to or from "DISABLED".
Depending on the value, it will enable or disable the appropriate DOM element.
void onDisabledChanged(bool isDisabled);