updateModel abstract method
Update the model for a particular control with a new value.
Implementation
void updateModel(NgControl dir, dynamic value);
Update the model for a particular control with a new value.
void updateModel(NgControl dir, dynamic value);