NgControlStatus constructor
- @Deprecated('Use listeners or variable binding on the control itself instead. ' 'This adds overhead for every form control whether the class is ' 'used or not.')
- @Optional.new() @Self.new() NgControl? _cd
Implementation
@Deprecated(
'Use listeners or variable binding on the control itself instead. '
'This adds overhead for every form control whether the class is '
'used or not.')
NgControlStatus(@Optional() @Self() this._cd);